Package: gtkorphan
Tags: patch

Hi,

please use deborphan's forward compatible options
--all-packages-pristine and --show-deps-pristine instead of
--all-packages and --show-deps.


The output format of --all-packages will need to change when Debian
replaces sections with tags and the output format of --show-deps is kind
of ugly and thus might change too.  To provide a non-changing interface
for deborphan's frontends, the options --all-packages-pristine and
--show-deps-pristine have been introduced a while ago.  After checking
all known reverse dependencies (except of one that is broken anyway and
presumably will be removed from Debian soon), it has been noticed that
gtkorphan is the only package in Debian that needs them.

More information about these options can be found in the file
'/usr/share/doc/deborphan/README.frontends', which is shipped in
deborphan 1.7.28.6 and later.


Uploading this change in the time frame from now (Ubuntu LTS is
releasing today) to the upcoming freeze of Debian Wheezy guarantees that
the installed deborphan release provides these options (even during
partial updates and without the need to add a versioned dependency) and
also ensures that during the next Debian release cycle deborphan is able
to adapt the output of --all-packages or --show-deps if needed without
breaking gtkorphan.


I attached a patch that contains the needed changes.  I have not yet
tried to build with this patch, anyway, this patch is trivial enough to
assume that it will not cause any breakage.

Please also consider adding the Spanish translation file that can be
found in the bug http://bugs.debian.org/537825 to your gtkorphan upload.


Regards
Carsten


P.S.: The bugs I reported two days ago were found during checking
      deborphan's reverse dependencies and are, unlike this one, not
      important to be fixed soon (or even to be fixed at all).
diff --git a/lib/gtkorphan_ops.pm b/lib/gtkorphan_ops.pm
index 6b2581b..b85ed4d 100644
--- a/lib/gtkorphan_ops.pm
+++ b/lib/gtkorphan_ops.pm
@@ -227,7 +227,7 @@ sub get_orphan_options
 	$options .= " --find-config" if ($find_config->get_active()) ;
 	
 	#all packages checked?
-	$options .= " --all-packages" if ($find_all->get_active()) ;
+	$options .= " --all-packages-pristine" if ($find_all->get_active()) ;
 	
 	
 	#GUESS options
@@ -608,7 +608,7 @@ sub populate_regular
 	$application->tv_regular->set_sensitive(TRUE);
 
 	#get orphaned to remove from list
 	#(deborphan bug on -d option
 	$command = $application->dorph;
 	my @orphaned = `$command`;
 	chomp (@orphaned);
@@ -617,7 +617,7 @@ sub populate_regular
 
 	
 	#build and spawn command line
-	$command = $application->dorph." -Psz -d".$options;
+	$command = $application->dorph." -Psz --show-deps-pristine".$options;
 	my @libraries = `$command`;
 	chomp (@libraries);
 	
@@ -666,7 +666,7 @@ sub get_regular_options {
 	$check_all=$gtkorphan_app::gladexml->get_widget('check_all_regular');
 	
 	#check_all checked?
-	$options .= " -a" if ($check_all->get_active()) ;
+	$options .= " --all-packages-pristine" if ($check_all->get_active()) ;
 
 	
 	return $options;
@@ -608,7 +608,7 @@ sub populate_regular
 
 	#get orphaned to remove from list
-	#(deborphan bug on -d option
+	#(deborphan bug on --show-deps-pristine option
 	$command = $application->dorph;
 	my @orphaned = `$command`;

Reply via email to